export function float__to_data(value: number): number {
  return value;
}

// eslint-disable-next-line @typescript-eslint/no-explicit-any
export function float__from_data(data: any): number {
  if (typeof data !== "number") {
    {{RAISE_DESERIALIZATION_ERROR}};
  }
  return data;
}