export type int = number;
export type int__DATA = number;

export function int__to_data(value: number): number {
  if (!Number.isInteger(value)) {
    {{RAISE_SERIALIZATION_ERROR}};
  }
  return value;
}

// eslint-disable-next-line @typescript-eslint/no-explicit-any
export function int__from_data(data: any): number {
  if (typeof data !== "number") {
    {{RAISE_DESERIALIZATION_ERROR}};
  }
  if (!Number.isInteger(data)) {
    {{RAISE_DESERIALIZATION_ERROR}};
  }
  return data;
}